(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     17283,        539]
NotebookOptionsPosition[     16701,        515]
NotebookOutlinePosition[     17055,        531]
CellTagsIndexPosition[     17012,        528]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Derivation", " ", "of", " ", "dynamics", " ", "of", " ", "rimless", " ", 
    "wheel", "\[IndentingNewLine]", "Fumihiko", " ", "Asano", 
    "\[IndentingNewLine]", "2012.2", ".23"}], "\[IndentingNewLine]", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"X", "=", 
     RowBox[{"x", "+", 
      RowBox[{"L", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"z", "+", 
      RowBox[{"L", " ", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dX", "=", 
     RowBox[{"dx", "+", 
      RowBox[{"L", " ", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", "d\[Theta]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dZ", "=", 
     RowBox[{"dz", "-", 
      RowBox[{"L", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}], "d\[Theta]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"K", "=", 
     RowBox[{
      RowBox[{"m", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"dX", "^", "2"}], "+", 
          RowBox[{"dZ", "^", "2"}]}], ")"}], "/", "2"}]}], "+", 
      RowBox[{"I0", " ", 
       RowBox[{
        RowBox[{"d\[Theta]", "^", "2"}], "/", "2"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Line1", "=", 
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{"K", ",", "dx"}], "]"}], ",", 
        RowBox[{"Constants", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"I0", ",", "L", ",", "m"}], "}"}]}]}], "]"}], "-", 
      RowBox[{"D", "[", 
       RowBox[{"K", ",", "x"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Line2", "=", 
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{"K", ",", "dz"}], "]"}], ",", 
        RowBox[{"Constants", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"I0", ",", "L", ",", "m"}], "}"}]}]}], "]"}], "-", 
      RowBox[{"D", "[", 
       RowBox[{"K", ",", "z"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Line3", "=", 
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{"K", ",", "d\[Theta]"}], "]"}], ",", 
        RowBox[{"Constants", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"I0", ",", "L", ",", "m"}], "}"}]}]}], "]"}], "-", 
      RowBox[{"D", "[", 
       RowBox[{"K", ",", "\[Theta]"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Line1", "=", 
     RowBox[{"Line1", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Dt", "[", 
          RowBox[{"dx", ",", 
           RowBox[{"Constants", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"I0", ",", "L", ",", "m"}], "}"}]}]}], "]"}], "\[Rule]", 
         "ddx"}], ",", 
        RowBox[{
         RowBox[{"Dt", "[", 
          RowBox[{"d\[Theta]", ",", 
           RowBox[{"Constants", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"I0", ",", "L", ",", "m"}], "}"}]}]}], "]"}], "\[Rule]", 
         "dd\[Theta]"}], ",", 
        RowBox[{
         RowBox[{"Dt", "[", 
          RowBox[{"\[Theta]", ",", 
           RowBox[{"Constants", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"I0", ",", "L", ",", "m"}], "}"}]}]}], "]"}], "\[Rule]", 
         "d\[Theta]"}]}], "}"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"FullSimplify", "[", "%", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Line2", "=", 
     RowBox[{"Line2", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Dt", "[", 
          RowBox[{"dz", ",", 
           RowBox[{"Constants", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"I0", ",", "L", ",", "m"}], "}"}]}]}], "]"}], "\[Rule]", 
         "ddz"}], ",", 
        RowBox[{
         RowBox[{"Dt", "[", 
          RowBox[{"d\[Theta]", ",", 
           RowBox[{"Constants", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"I0", ",", "L", ",", "m"}], "}"}]}]}], "]"}], "\[Rule]", 
         "dd\[Theta]"}], ",", 
        RowBox[{
         RowBox[{"Dt", "[", 
          RowBox[{"\[Theta]", ",", 
           RowBox[{"Constants", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"I0", ",", "L", ",", "m"}], "}"}]}]}], "]"}], "\[Rule]", 
         "d\[Theta]"}]}], "}"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"FullSimplify", "[", "%", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Line3", "=", 
     RowBox[{"Line3", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Dt", "[", 
          RowBox[{"d\[Theta]", ",", 
           RowBox[{"Constants", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"I0", ",", "L", ",", "m"}], "}"}]}]}], "]"}], "\[Rule]", 
         "dd\[Theta]"}], ",", 
        RowBox[{
         RowBox[{"Dt", "[", 
          RowBox[{"\[Theta]", ",", 
           RowBox[{"Constants", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"I0", ",", "L", ",", "m"}], "}"}]}]}], "]"}], "\[Rule]", 
         "d\[Theta]"}], ",", 
        RowBox[{
         RowBox[{"Dt", "[", 
          RowBox[{"dx", ",", 
           RowBox[{"Constants", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"I0", ",", "L", ",", "m"}], "}"}]}]}], "]"}], "\[Rule]", 
         "ddx"}], ",", 
        RowBox[{
         RowBox[{"Dt", "[", 
          RowBox[{"dz", ",", 
           RowBox[{"Constants", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"I0", ",", "L", ",", "m"}], "}"}]}]}], "]"}], "\[Rule]", 
         "ddz"}]}], "}"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"FullSimplify", "[", "%", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5389740417786903`*^9, 3.5389745160599403`*^9}, {
  3.5389749824505653`*^9, 3.5389749933411903`*^9}}],

Cell[BoxData[
 RowBox[{"m", " ", 
  RowBox[{"(", 
   RowBox[{"ddx", "+", 
    RowBox[{"dd\[Theta]", " ", "L", " ", 
     RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["d\[Theta]", "2"], " ", "L", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.5389744773411903`*^9, 3.5389744911849403`*^9}, 
   3.5389749996380653`*^9}],

Cell[BoxData[
 RowBox[{"m", " ", 
  RowBox[{"(", 
   RowBox[{"ddz", "-", 
    RowBox[{"L", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["d\[Theta]", "2"], " ", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "+", 
       RowBox[{"dd\[Theta]", " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.5389744773411903`*^9, 3.5389744911849403`*^9}, 
   3.5389749996380653`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dd\[Theta]", " ", 
   RowBox[{"(", 
    RowBox[{"I0", "+", 
     RowBox[{
      SuperscriptBox["L", "2"], " ", "m"}]}], ")"}]}], "+", 
  RowBox[{"ddx", " ", "L", " ", "m", " ", 
   RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
  RowBox[{"ddz", " ", "L", " ", "m", " ", 
   RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.5389744773411903`*^9, 3.5389744911849403`*^9}, 
   3.5389749996380653`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Derivation", " ", "of", " ", "M", " ", "matrix"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"M", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"M", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "1"}], "]"}], "]"}], "=", 
     RowBox[{"D", "[", 
      RowBox[{"Line1", ",", "ddx"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"M", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}], "=", 
     RowBox[{"D", "[", 
      RowBox[{"Line1", ",", "ddz"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"M", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "3"}], "]"}], "]"}], "=", 
     RowBox[{"D", "[", 
      RowBox[{"Line1", ",", "dd\[Theta]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"M", "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "1"}], "]"}], "]"}], "=", 
     RowBox[{"D", "[", 
      RowBox[{"Line2", ",", "ddx"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"M", "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "2"}], "]"}], "]"}], "=", 
     RowBox[{"D", "[", 
      RowBox[{"Line2", ",", "ddz"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"M", "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "3"}], "]"}], "]"}], "=", 
     RowBox[{"D", "[", 
      RowBox[{"Line2", ",", "dd\[Theta]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"M", "[", 
      RowBox[{"[", 
       RowBox[{"3", ",", "1"}], "]"}], "]"}], "=", 
     RowBox[{"D", "[", 
      RowBox[{"Line3", ",", "ddx"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"M", "[", 
      RowBox[{"[", 
       RowBox[{"3", ",", "2"}], "]"}], "]"}], "=", 
     RowBox[{"D", "[", 
      RowBox[{"Line3", ",", "ddz"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"M", "[", 
      RowBox[{"[", 
       RowBox[{"3", ",", "3"}], "]"}], "]"}], "=", 
     RowBox[{"D", "[", 
      RowBox[{"Line3", ",", "dd\[Theta]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"M", "=", 
     RowBox[{"FullSimplify", "[", "M", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Derivation", " ", "of", " ", "h", " ", "vector"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"h", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "0", "}"}], ",", 
       RowBox[{"{", "0", "}"}], ",", 
       RowBox[{"{", "0", "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "1"}], "]"}], "]"}], "=", 
     RowBox[{"Line1", "-", 
      RowBox[{
       RowBox[{"M", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "ddx"}], "-", 
      RowBox[{
       RowBox[{"M", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}], "ddz"}], "-", 
      RowBox[{
       RowBox[{"M", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}], "dd\[Theta]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "1"}], "]"}], "]"}], "=", 
     RowBox[{"Line2", "-", 
      RowBox[{
       RowBox[{"M", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "1"}], "]"}], "]"}], "ddx"}], "-", 
      RowBox[{
       RowBox[{"M", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}], "ddz"}], "-", 
      RowBox[{
       RowBox[{"M", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}], "dd\[Theta]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{"[", 
       RowBox[{"3", ",", "1"}], "]"}], "]"}], "=", 
     RowBox[{"Line3", "-", 
      RowBox[{
       RowBox[{"M", "[", 
        RowBox[{"[", 
         RowBox[{"3", ",", "1"}], "]"}], "]"}], "ddx"}], "-", 
      RowBox[{
       RowBox[{"M", "[", 
        RowBox[{"[", 
         RowBox[{"3", ",", "2"}], "]"}], "]"}], "ddz"}], "-", 
      RowBox[{
       RowBox[{"M", "[", 
        RowBox[{"[", 
         RowBox[{"3", ",", "3"}], "]"}], "]"}], "dd\[Theta]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Potential", " ", "energy"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"P", "=", 
     RowBox[{"m", " ", "g", " ", "Z"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "1"}], "]"}], "]"}], "=", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
      RowBox[{"D", "[", 
       RowBox[{"P", ",", "x"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "1"}], "]"}], "]"}], "=", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "1"}], "]"}], "]"}], "+", 
      RowBox[{"D", "[", 
       RowBox[{"P", ",", "z"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{"[", 
       RowBox[{"3", ",", "1"}], "]"}], "]"}], "=", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"[", 
        RowBox[{"3", ",", "1"}], "]"}], "]"}], "+", 
      RowBox[{"D", "[", 
       RowBox[{"P", ",", "\[Theta]"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"h", "=", 
     RowBox[{"FullSimplify", "[", "h", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"MatrixForm", "[", "M", "]"}], "\[IndentingNewLine]", 
   RowBox[{"MatrixForm", "[", "h", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5389745267630653`*^9, 3.5389745448724403`*^9}, {
  3.5389745791849403`*^9, 3.5389748672005653`*^9}, {3.5389749220911903`*^9, 
  3.5389749672318153`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"m", "0", 
      RowBox[{"L", " ", "m", " ", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}]}]},
     {"0", "m", 
      RowBox[{
       RowBox[{"-", "L"}], " ", "m", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}]},
     {
      RowBox[{"L", " ", "m", " ", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}]}], 
      RowBox[{
       RowBox[{"-", "L"}], " ", "m", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
      RowBox[{"I0", "+", 
       RowBox[{
        SuperscriptBox["L", "2"], " ", "m"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.5389745408255653`*^9, 3.5389745453411903`*^9}, 
   3.5389746485130653`*^9, {3.5389747861380653`*^9, 3.5389748675286903`*^9}, 
   3.5389750019349403`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["d\[Theta]", "2"]}], " ", "L", " ", "m", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}]},
     {
      RowBox[{"m", " ", 
       RowBox[{"(", 
        RowBox[{"g", "-", 
         RowBox[{
          SuperscriptBox["d\[Theta]", "2"], " ", "L", " ", 
          RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ")"}]}]},
     {
      RowBox[{
       RowBox[{"-", "g"}], " ", "L", " ", "m", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.5389745408255653`*^9, 3.5389745453411903`*^9}, 
   3.5389746485130653`*^9, {3.5389747861380653`*^9, 3.5389748675286903`*^9}, 
   3.5389750019505653`*^9}]
}, Open  ]]
},
WindowSize->{1672, 946},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (2009\:5e744\:670823\
\:65e5)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 5938, 172, 1305, "Input"],
Cell[6508, 196, 401, 10, 63, "Output"],
Cell[6912, 208, 468, 14, 63, "Output"],
Cell[7383, 224, 460, 12, 63, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7880, 241, 6324, 199, 1305, "Input"],
Cell[14207, 442, 1241, 34, 154, "Output"],
Cell[15451, 478, 1234, 34, 159, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

